<?php

/**
 * @license LGPLv3, http://opensource.org/licenses/LGPL-3.0
 * @copyright Metaways Infosystems GmbH, 2012
 * @copyright Aimeos (aimeos.org), 2015-2023
 */

/* Available data:
 * - detailProductItem : Product item incl. referenced items
 */


$enc = $this->encoder();

/** client/html/basket/require-stock
 * Customers can order products only if there are enough products in stock
 *
 * Checks that the requested product quantity is in stock before
 * the customer can add them to his basket and order them. If there
 * are not enough products available, the customer will get a notice.
 *
 * @param boolean True if products must be in stock, false if products can be sold without stock
 * @since 2014.03
 */
$reqstock = (int)$this->config('client/html/basket/require-stock', true);

/** client/html/catalog/detail/basket-add
 * Display the "add to basket" button for each suggested/bought-together product item
 *
 * Enables the button for adding products to the basket for the related products
 * in the basket. This works for all type of products, even for selection products
 * with product variants and product bundles. By default, also optional attributes
 * are displayed if they have been associated to a product.
 *
 * To fetch the variant articles of selection products too, add this setting to
 * your configuration:
 *
 * mshop/common/manager/maxdepth = 3
 *
 * @param boolean True to display the button, false to hide it
 * @since 2021.04
 * @see client/html/catalog/home/basket-add
 * @see client/html/catalog/lists/basket-add
 * @see client/html/catalog/product/basket-add
 * @see client/html/basket/related/basket-add
 */

$varAttr = [];
if (isset($this->detailProductItem)
    && ($articleId = $this->param('d_articleid'))
    && ($listItem = $this->detailProductItem->getListItem('product', 'default', $articleId))
    && ($article = $listItem->getRefItem())
) {
    $varAttr = $article->getRefItems('attribute', null, 'variant')->col('attribute.id', 'attribute.type');
}

$attrTypes = $this->get('detailAttributeTypes', []);
$propTypes = $this->get('detailPropertyTypes', []);

$attrTypeName = function (string $code) use ($attrTypes) {
    return isset($attrTypes[$code]) && $attrTypes[$code]->getName() !== $attrTypes[$code]->getLabel(
    ) ? $attrTypes[$code]->getName() : $this->translate('client/code', $code);
};

$propTypeName = function (string $code) use ($propTypes) {
    return isset($propTypes[$code]) && $propTypes[$code]->getName() !== $propTypes[$code]->getLabel(
    ) ? $propTypes[$code]->getName() : $this->translate('client/code', $code);
};


?>
<?php
if (isset($this->detailProductItem)) { ?>
    <div class="breadcrumb-area gray-bg-7">
        <div class="container">
            <div class="breadcrumb-content">
                <ul>
                    <?php
                    if (!($suppliers = $this->detailProductItem->getRefItems('supplier'))->isEmpty()) {
                        $name = $suppliers->getName()->first() ?>
                        <li>
                            <a href="<?= $enc->attr(
                                $this->link(
                                    'client/html/supplier/detail/url',
                                    ['f_supid' => $suppliers->firstKey(), 's_name' => $name]
                                )
                            ) ?>">
                                <?= $enc->html($name, $enc::TRUST) ?>
                            </a>
                        </li>
                        <?php
                    } elseif ($siteItem = $this->detailProductItem->getSiteItem()) { ?>
                        <li><?= $enc->html($siteItem->getLabel()) ?></li>
                        <?php
                    } ?>
                    <li class="active">Product Details Tab</li>
                </ul>
            </div>
        </div>
    </div>
    <div class="product-details pt-65 pb-65">
        <div class="container">
            <div class="row">
                <div class="col-lg-6 col-md-12">
                    <div class="product-details-img">

                        <?= $this->partial(
                            $this->config('client/html/catalog/detail/partials/image', 'catalog/detail/image'),
                            ['mediaItems' => $this->get('detailMediaItems', map()), 'params' => $this->param()]
                        ) ?>

                    </div>
                </div>
                <div class="col-lg-6 col-md-12">
                    <div class="product-details-content">
                        <h4><?= $enc->html($this->detailProductItem->getName(), $enc::TRUST) ?></h4>
                        <div class="in-stock">
                            <p>
                                <?= $enc->html($this->translate('client', 'Article no.'), $enc::TRUST) ?> :
                                <span class="value" itemprop="sku"><?= $enc->html(
                                        $this->detailProductItem->getCode()
                                    ) ?></span>
                            </p>
                        </div>
                        <div class="rating-review">
                            <?php
                            if ($this->detailProductItem->getRating() > 0) { ?>
                                <div class="pro-dec-rating" itemscope itemprop="aggregateRating"
                                     itemtype="http://schema.org/AggregateRating">
                                    <?= str_repeat(
                                        '<i class="ion-android-star-outline theme-star"></i>',
                                        (int)round($this->detailProductItem->getRating())
                                    ) ?>
                                </div>
                                <?php
                            } ?>

                            <div class="pro-dec-review">
                                <ul>
                                    <li><?= $enc->html($this->detailProductItem->getRatings()) ?> <?= $enc->html($this->translate('client', 'Reviews'), $enc::TRUST) ?></li>
                                    <li><?= $enc->html($this->translate('client', 'Add Your Reviews'), $enc::TRUST) ?></li>
                                </ul>
                            </div>
                        </div>
                        <?php
                        $refItem = $this->detailProductItem->getlistItems("price")->first()->getRefItem()->get(
                            'price.value'
                        );
                        ?>
                        <span>$ <?= $refItem ?></span>
                        <div class="price-list">
                            <?php
                            if ($this->detailProductItem->getType() === 'select') { ?>
                                <?php
                                foreach (
                                    $this->detailProductItem->getRefItems(
                                        'product',
                                        'default',
                                        'default'
                                    ) as $prodid => $product
                                ) { ?>

                                    <?php
                                    if (!($prices = $product->getRefItems('price', null, 'default'))->isEmpty()) { ?>
                                        <div class="articleitem price" data-prodid="<?= $enc->attr($prodid) ?>">
                                            <?= $this->partial(
                                                $this->config(
                                                    'client/html/common/partials/price',
                                                    'common/partials/price'
                                                ),
                                                ['prices' => $prices]
                                            ) ?>
                                        </div>
                                        <?php
                                    } ?>
                                    <?php
                                } ?>
                                <?php
                            } ?>
                        </div>


                        <div class="in-stock">
                            <p><?= $enc->html($this->translate('client', 'Available'), $enc::TRUST)?>: <span>In stock</span></p>
                        </div>

                        <?php
                        foreach ($this->detailProductItem->getRefItems('text', 'short', 'default') as $textItem) { ?>
                            <p><?= $enc->html($textItem->getContent(), $enc::TRUST) ?></p>
                            <?php
                        } ?>


                        <div class="catalog-detail-basket" itemscope itemprop="offers"
                             itemtype="http://schema.org/Offer"
                             aria-label="<?= $enc->attr($this->translate('client', 'Product price')) ?>">

                            <form class="basket" method="POST"
                                  action="<?= $enc->attr($this->link('client/html/basket/standard/url')) ?>">
                                <?= $this->csrf()->formfield() ?>
                                <?php
                                if ($this->detailProductItem->getType() === 'select') { ?>

                                    <div class="catalog-detail-basket-selection">

                                        <?= $this->partial(
                                        /** client/html/common/partials/selection
                                         * Relative path to the variant attribute partial template file
                                         *
                                         * Partials are templates which are reused in other templates and generate
                                         * reoccuring blocks filled with data from the assigned values. The selection
                                         * partial creates an HTML block for a list of variant product attributes
                                         * assigned to a selection product a customer must select from.
                                         *
                                         * The partial template files are usually stored in the templates/partials/ folder
                                         * of the core or the extensions. The configured path to the partial file must
                                         * be relative to the templates/ folder, e.g. "common/partials/selection".
                                         *
                                         * @param string Relative path to the template file
                                         * @since 2015.04
                                         * @see client/html/common/partials/attribute
                                         */
                                            $this->config(
                                                'client/html/common/partials/selection',
                                                'common/partials/selection'
                                            ),
                                            [
                                                'productItems' => $this->detailProductItem->getRefItems(
                                                    'product',
                                                    null,
                                                    'default'
                                                ),
                                                'productItem' => $this->detailProductItem,
                                                'attributeTypes' => $attrTypes
                                            ]
                                        ) ?>

                                    </div>

                                <?php
                                } elseif ($this->detailProductItem->getType() === 'group') { ?>

                                    <div class="catalog-detail-basket-selection">

                                        <?= $this->partial(
                                        /** client/html/catalog/detail/partials/group
                                         * Relative path to the group product partial template file
                                         *
                                         * Partials are templates which are reused in other templates and generate
                                         * reoccuring blocks filled with data from the assigned values. The group
                                         * partial creates an HTML block for a list of sub-products assigned to a
                                         * group product a customer can select from.
                                         *
                                         * @param string Relative path to the template file
                                         * @since 2021.07
                                         * @see client/html/common/partials/attribute
                                         */
                                            $this->config(
                                                'client/html/catalog/detail/partials/group',
                                                'catalog/detail/group'
                                            ),
                                            [
                                                'productItems' => $this->detailProductItem->getRefItems(
                                                    'product',
                                                    null,
                                                    'default'
                                                ),
                                                'productItem' => $this->detailProductItem,
                                                'attributeTypes' => $attrTypes
                                            ]
                                        ) ?>

                                    </div>

                                    <?php
                                } ?>

                                <div class="catalog-detail-basket-attribute">

                                    <?= $this->partial(
                                    /** client/html/common/partials/attribute
                                     * Relative path to the product attribute partial template file
                                     *
                                     * Partials are templates which are reused in other templates and generate
                                     * reoccuring blocks filled with data from the assigned values. The attribute
                                     * partial creates an HTML block for a list of optional product attributes a
                                     * customer can select from.
                                     *
                                     * The partial template files are usually stored in the templates/partials/ folder
                                     * of the core or the extensions. The configured path to the partial file must
                                     * be relative to the templates/ folder, e.g. "partials/attribute.php".
                                     *
                                     * @param string Relative path to the template file
                                     * @since 2016.01
                                     * @see client/html/common/partials/selection
                                     */
                                        $this->config(
                                            'client/html/common/partials/attribute',
                                            'common/partials/attribute'
                                        ),
                                        [
                                            'productItem' => $this->detailProductItem,
                                            'attributeTypes' => $attrTypes
                                        ]
                                    ) ?>

                                </div>


                                <div class="stock-list">
                                    <div class="articleitem <?= !in_array(
                                        $this->detailProductItem->getType(),
                                        ['select', 'group']
                                    ) ? 'stock-actual' : '' ?>"
                                         data-prodid="<?= $enc->attr($this->detailProductItem->getId()) ?>">
                                    </div>

                                    <?php
                                    foreach (
                                        $this->detailProductItem->getRefItems(
                                            'product',
                                            null,
                                            'default'
                                        ) as $articleId => $articleItem
                                    ) { ?>
                                        <div class="articleitem" data-prodid="<?= $enc->attr($articleId) ?>"></div>
                                        <?php
                                    } ?>

                                </div>


                                <?php
                                if (!$this->detailProductItem->getRefItems('price', 'default', 'default')->empty()) { ?>
                                    <div class="addbasket">
                                        <input type="hidden" value="add"
                                               name="<?= $enc->attr($this->formparam('b_action')) ?>">
                                        <input type="hidden"
                                               name="<?= $enc->attr($this->formparam(['b_prod', 0, 'stocktype'])) ?>"
                                               value="<?= $enc->attr(
                                                   $this->get('detailStockTypes', map())->first()
                                               ) ?>">
                                        <input type="hidden"
                                               name="<?= $enc->attr($this->formparam(['b_prod', 0, 'prodid'])) ?>"
                                               value="<?= $enc->attr($this->detailProductItem->getId()) ?>">
                                        <div class="input-group group-add-to-cart">
                                            <?php
                                            if ($this->detailProductItem->getType() !== 'group') { ?>
                                                <input type="number"
                                                       class="form-control custom-form" <?= !$this->detailProductItem->isAvailable(
                                                ) ? 'disabled' : '' ?>
                                                       name="<?= $enc->attr($this->formparam(['b_prod', 0, 'quantity'])
                                                       ) ?>"
                                                       step="<?= $enc->attr($this->detailProductItem->getScale()) ?>"
                                                       min="<?= $enc->attr($this->detailProductItem->getScale()) ?>"
                                                       max="2147483647"
                                                       value="<?= $enc->attr($this->detailProductItem->getScale()) ?>"
                                                       required="required"
                                                       title="<?= $enc->attr($this->translate('client', 'Quantity')) ?>"
                                                >
                                                <?php
                                            } ?>
                                            <button class="action-cart" type="submit"
                                                    value="" <?= !$this->detailProductItem->isAvailable(
                                            ) ? 'disabled' : '' ?>>
                                                <?= $enc->html(
                                                    $this->translate('client', 'Add to basket'),
                                                    $enc::TRUST
                                                ) ?>
                                            </button>
                                        </div>
                                    </div>
                                    <?php
                                } ?>

                            </form>

                        </div>

                    </div>
                </div>
            </div>
        </div>
    </div>
    <div class="description-review-area pt-25 pb-70">
        <div class="container">
            <div class="description-review-wrapper">
                <div class="description-review-topbar nav text-center">
                    <a class="active" data-bs-toggle="tab" href="#des-details1"><?= $enc->html($this->translate('client', 'Description'), $enc::TRUST) ?></a>
                    <a data-bs-toggle="tab" href="#des-details2"><?= $enc->html($this->translate('client', 'Tags'), $enc::TRUST) ?> </a>
                    <a data-bs-toggle="tab" href="#des-details3">
                        <?= $enc->html($this->translate('client', 'Reviews'), $enc::TRUST) ?>
                        <span class="rev-span"><?= $enc->html($this->detailProductItem->getRatings()) ?></span>
                    </a>
                </div>
                <div class="tab-content description-review-bottom">
                    <div id="des-details1" class="tab-pane active">
                        <div class="product-description-wrapper">
                            <?php
                            if (!($textItems = $this->detailProductItem->getRefItems('text', 'long'))->isEmpty()) { ?>
                                <div class="block description">
                                    <?php
                                    foreach ($textItems as $textItem) { ?>
                                        <div class="long item"><?= $enc->html(
                                                $textItem->getContent(),
                                                $enc::TRUST
                                            ) ?></div>
                                        <?php
                                    } ?>
                                </div>
                                <?php
                            } ?>
                        </div>
                    </div>
                    <div id="des-details2" class="tab-pane">
                        <div class="product-anotherinfo-wrapper">
                            <ul>
                                <li><span>Tags:</span></li>
                                <li><a href="#"> Fashion,</a></li>
                                <li><a href="#"> Office Furniture,</a></li>
                                <li><a href="#"> Sports,</a></li>
                                <li><a href="#"> Jewelry,</a></li>
                                <li><a href="#"> watch</a></li>
                            </ul>
                        </div>
                    </div>
                    <div id="des-details3" class="tab-pane">
                        <div class="rattings-wrapper">
                            <div class="reviews container-fluid block"
                                 data-productid="<?= $enc->attr($this->detailProductItem->getId()) ?>">
                                <div class="row">
                                    <div class="col-md-4 rating-list">
                                        <div class="rating-numbers d-flex gap-1 justify-content-between">
                                            <div class="rating-num"><?= number_format(
                                                    $this->detailProductItem->getRating(),
                                                    1
                                                ) ?>/5
                                            </div>
                                            <div class="rating-total"><?= $enc->html(
                                                    sprintf(
                                                        $this->translate(
                                                            'client',
                                                            '%1$d review',
                                                            '%1$d reviews',
                                                            $this->detailProductItem->getRatings()
                                                        ),
                                                        $this->detailProductItem->getRatings()
                                                    )
                                                ) ?></div>
                                        </div>
                                        <div class="rating-dist"
                                             data-ratings="<?= $enc->attr($this->detailProductItem->getRatings()) ?>">
                                            <div class="d-flex justify-content-between">
                                                <div class="rating-label col-4">
                                                    <label for="rating-5" class="ratting-star">
                                                        <i class="ion-android-star-outline theme-star"></i>
                                                        <i class="ion-android-star-outline theme-star"></i>
                                                        <i class="ion-android-star-outline theme-star"></i>
                                                        <i class="ion-android-star-outline theme-star"></i>
                                                        <i class="ion-android-star-outline theme-star"></i>
                                                    </label>
                                                </div>
                                                <div class="rating-percent col-8 d-flex align-items-center">
                                                    <progress class="w-100" id="rating-5" value="0" max="100">0
                                                    </progress>
                                                </div>
                                            </div>
                                            <div class="d-flex justify-content-between">
                                                <div class="rating-label col-4">
                                                    <label for="rating-4" class="ratting-star">
                                                        <i class="ion-android-star-outline theme-star"></i>
                                                        <i class="ion-android-star-outline theme-star"></i>
                                                        <i class="ion-android-star-outline theme-star"></i>
                                                        <i class="ion-android-star-outline theme-star"></i>
                                                    </label>
                                                </div>
                                                <div class="rating-percent col-8 d-flex align-items-center">
                                                    <progress class="w-100" id="rating-5" value="0" max="100">0
                                                    </progress>
                                                </div>
                                            </div>
                                            <div class="d-flex justify-content-between">
                                                <div class="rating-label col-4">
                                                    <label for="rating-4" class="ratting-star">
                                                        <i class="ion-android-star-outline theme-star"></i>
                                                        <i class="ion-android-star-outline theme-star"></i>
                                                        <i class="ion-android-star-outline theme-star"></i>
                                                    </label>
                                                </div>
                                                <div class="rating-percent col-8 d-flex align-items-center">
                                                    <progress class="w-100" id="rating-5" value="0" max="100">0
                                                    </progress>
                                                </div>
                                            </div>
                                            <div class="d-flex justify-content-between">
                                                <div class="rating-label col-4">
                                                    <label for="rating-4" class="ratting-star">
                                                        <i class="ion-android-star-outline theme-star"></i>
                                                        <i class="ion-android-star-outline theme-star"></i>
                                                    </label>
                                                </div>
                                                <div class="rating-percent col-8 d-flex align-items-center">
                                                    <progress class="w-100" id="rating-5" value="0" max="100">0
                                                    </progress>
                                                </div>
                                            </div>
                                            <div class="d-flex justify-content-between">
                                                <div class="rating-label col-4">
                                                    <label for="rating-4" class="ratting-star">
                                                        <i class="ion-android-star-outline theme-star"></i>
                                                    </label>
                                                </div>
                                                <div class="rating-percent col-8 d-flex align-items-center">
                                                    <progress class="w-100" id="rating-5" value="0" max="100">0
                                                    </progress>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <div class="container">
        <?php
        if (!($products = $this->detailProductItem->getRefItems('product', null, 'suggestion'))->isEmpty()) { ?>
            <div class="section-border full-w mb-10">
                <h4 class="section-title section-bg-white"><?= $this->translate('client', 'Suggested products') ?></h4>
            </div>
            <div class="headphone-slider-active product-slider owl-carousel nav-style">
                <?= $this->partial(
                    $this->config('client/html/common/partials/products', 'common/partials/products'), [
                        'basket-add' => $this->config('client/html/catalog/detail/basket-add', false),
                        'products' => $products,
                        'itemprop' => 'isRelatedTo'
                    ]
                )
                ?>
            </div>
            <?php
        } ?>
    </div>
    <?php
} ?>

